changeset 2191:7331f3c13fd7

Mac: Copy text color to the NSTabelCellView's text field from the container.
author bsmith@81767d24-ef19-dc11-ae90-00e081727c95
date Thu, 15 Oct 2020 18:01:15 +0000
parents 4cb258fb6729
children 214e1ea303e2
files mac/dw.m
diffstat 1 files changed, 10 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/mac/dw.m	Thu Oct 15 04:45:11 2020 +0000
+++ b/mac/dw.m	Thu Oct 15 18:01:15 2020 +0000
@@ -2641,9 +2641,17 @@
         
         _dw_table_cell_view_layout(result);
         
         /* Copy the alignment setting from the column */
         if([result textField])
-            [[result textField] setAlignment:align];
+        {
+            NSTextField *tf = [result textField];
+            
+            [tf setAlignment:align];
+            if(fgcolor)
+                [tf setTextColor:fgcolor];
+        }
         
         /* Return the result */
         return result;
@@ -2641,9 +2641,17 @@
         _dw_table_cell_view_layout(result);
         
-        /* Copy the alignment setting from the column */
+        /* Copy the alignment setting from the column,
+         * and set the text color from the container.
+         */
         if([result textField])